==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEERATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour EMPLOYEERATEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEERATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATESUPPLIRCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATESUPPLIRORGCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATETRADECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEERATESTARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEERATEID_Type", propOrder = {
    "departmentid",
    "empratesupplircode",
    "empratesupplirorgcode",
    "empratetradecode",
    "employee",
    "organizationid",
    "employeeratestartdate",
    "occupationtypecode"
})
public class EMPLOYEERATEID_Type {

    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "EMPRATESUPPLIRCODE", defaultValue = "*")
    protected String empratesupplircode;
    @XmlElement(name = "EMPRATESUPPLIRORGCODE", defaultValue = "*")
    protected String empratesupplirorgcode;
    @XmlElement(name = "EMPRATETRADECODE", defaultValue = "*")
    protected String empratetradecode;
    @XmlElement(name = "EMPLOYEE", required = true)
    protected PERSONID_Type employee;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "EMPLOYEERATESTARTDATE", required = true)
    protected DATETIME employeeratestartdate;
    @XmlElement(name = "OCCUPATIONTYPECODE", required = true)
    protected String occupationtypecode;

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété empratesupplircode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATESUPPLIRCODE() {
        return empratesupplircode;
    }

    /**
     * Définit la valeur de la propriété empratesupplircode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATESUPPLIRCODE(String value) {
        this.empratesupplircode = value;
    }

    /**
     * Obtient la valeur de la propriété empratesupplirorgcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATESUPPLIRORGCODE() {
        return empratesupplirorgcode;
    }

    /**
     * Définit la valeur de la propriété empratesupplirorgcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATESUPPLIRORGCODE(String value) {
        this.empratesupplirorgcode = value;
    }

    /**
     * Obtient la valeur de la propriété empratetradecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATETRADECODE() {
        return empratetradecode;
    }

    /**
     * Définit la valeur de la propriété empratetradecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATETRADECODE(String value) {
        this.empratetradecode = value;
    }

    /**
     * Obtient la valeur de la propriété employee.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Définit la valeur de la propriété employee.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété employeeratestartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEMPLOYEERATESTARTDATE() {
        return employeeratestartdate;
    }

    /**
     * Définit la valeur de la propriété employeeratestartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEMPLOYEERATESTARTDATE(DATETIME value) {
        this.employeeratestartdate = value;
    }

    /**
     * Obtient la valeur de la propriété occupationtypecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOCCUPATIONTYPECODE() {
        return occupationtypecode;
    }

    /**
     * Définit la valeur de la propriété occupationtypecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOCCUPATIONTYPECODE(String value) {
        this.occupationtypecode = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEERATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for EMPLOYEERATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEERATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATESUPPLIRCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATESUPPLIRORGCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPRATETRADECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEERATESTARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEERATEID_Type", propOrder = {
    "departmentid",
    "empratesupplircode",
    "empratesupplirorgcode",
    "empratetradecode",
    "employee",
    "organizationid",
    "employeeratestartdate",
    "occupationtypecode"
})
public class EMPLOYEERATEID_Type {

    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "EMPRATESUPPLIRCODE", defaultValue = "*")
    protected String empratesupplircode;
    @XmlElement(name = "EMPRATESUPPLIRORGCODE", defaultValue = "*")
    protected String empratesupplirorgcode;
    @XmlElement(name = "EMPRATETRADECODE", defaultValue = "*")
    protected String empratetradecode;
    @XmlElement(name = "EMPLOYEE", required = true)
    protected PERSONID_Type employee;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "EMPLOYEERATESTARTDATE", required = true)
    protected DATETIME employeeratestartdate;
    @XmlElement(name = "OCCUPATIONTYPECODE", required = true)
    protected String occupationtypecode;

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the empratesupplircode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATESUPPLIRCODE() {
        return empratesupplircode;
    }

    /**
     * Sets the value of the empratesupplircode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATESUPPLIRCODE(String value) {
        this.empratesupplircode = value;
    }

    /**
     * Gets the value of the empratesupplirorgcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATESUPPLIRORGCODE() {
        return empratesupplirorgcode;
    }

    /**
     * Sets the value of the empratesupplirorgcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATESUPPLIRORGCODE(String value) {
        this.empratesupplirorgcode = value;
    }

    /**
     * Gets the value of the empratetradecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPRATETRADECODE() {
        return empratetradecode;
    }

    /**
     * Sets the value of the empratetradecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPRATETRADECODE(String value) {
        this.empratetradecode = value;
    }

    /**
     * Gets the value of the employee property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Sets the value of the employee property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the employeeratestartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEMPLOYEERATESTARTDATE() {
        return employeeratestartdate;
    }

    /**
     * Sets the value of the employeeratestartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEMPLOYEERATESTARTDATE(DATETIME value) {
        this.employeeratestartdate = value;
    }

    /**
     * Gets the value of the occupationtypecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOCCUPATIONTYPECODE() {
        return occupationtypecode;
    }

    /**
     * Sets the value of the occupationtypecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOCCUPATIONTYPECODE(String value) {
        this.occupationtypecode = value;
    }

}
